SimpleTimeFormat enum

A collection of simple time formats supported by the package.

Use SimpleTimeFormatExtension.pattern to obtain the corresponding DateFormat pattern string used for formatting or parsing.

Inline comments provide example outputs for each format.

Inheritance
Available extensions

Values

hhMmAmPm → const SimpleTimeFormat
hhMm → const SimpleTimeFormat
hHmm → const SimpleTimeFormat
hHmmss → const SimpleTimeFormat

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
pattern String

Available on SimpleTimeFormat, provided by the SimpleTimeFormatExtension extension

no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<SimpleTimeFormat>
A constant List of the values in this enum, in order of their declaration.