SimpleDateFormat enum
Supported date formats used throughout the package.
Each value corresponds to a human-readable pattern that can be retrieved via SimpleDateFormatExtension.pattern.
Examples are included in comments for quick reference.
- Inheritance
- Available extensions
Values
- yyyyMMdd → const SimpleDateFormat
- ddMMyyyy → const SimpleDateFormat
- ddMMMyyyy → const SimpleDateFormat
- mMMddyyyy → const SimpleDateFormat
- yyyyMMddSlash → const SimpleDateFormat
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - pattern → String
-
Available on SimpleDateFormat, provided by the SimpleDateFormatExtension extension
no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
SimpleDateFormat> - A constant List of the values in this enum, in order of their declaration.